@@ -50,8 +50,7 @@ class save:
         self.encoding: Encoding = Enum(
             "Encoding", ["NONE", "JSON", "BINARY", "CRYPTOGRAPHY", "CSV"]
         )
-        self.storage: Storage = Enum(
-            "Storage", ["NORMAL", "FTP", "GOOGLE", "OTHER"])
+        self.storage: Storage = Enum("Storage", ["NORMAL", "FTP", "GOOGLE", "OTHER"])
         self.DriveCredentialsEnum: DriveCredentialsMode = Enum(
             "DriveCredentialsMode", ["ADD", "DELETE"]
         )
@@ -78,8 +77,7 @@ class save:
             module = module[:-3]  # remove .py
             # Attempt to load the module
             try:
-                mdl = importlib.import_module(
-                    f"{SaveModules.__package__}.{module}")
+                mdl = importlib.import_module(f"{SaveModules.__package__}.{module}")
                 self.saveModules[module] = mdl.load()
             except (AttributeError, ModuleNotFoundError) as e:
                 Message.warn(
@@ -127,8 +125,7 @@ class save:
             )
 
             if data.get("Name") == "" or not correct:
-                data["Name"] = input(
-                    "Please enter your username for the FTP server: ")
+                data["Name"] = input("Please enter your username for the FTP server: ")
 
             data["Password"] = getpass.getpass(
                 "Please enter your password for the FTP server: "
@@ -170,8 +167,7 @@ class save:
         """
 
         key = self.enc.GetKey()  # get the byte version
-        self.settings["Passcode"] = key.decode(
-            "utf-8")  # store the byte as string
+        self.settings["Passcode"] = key.decode("utf-8")  # store the byte as string
 
         # save the data
         self.Save(
@@ -205,8 +201,7 @@ class save:
             str: The result of the action
         """
         if not os.path.exists(f"{path}/gCred.json"):
-            raise AttributeError(
-                "Couldn't find `gCred.json` in the path specified!")
+            raise AttributeError("Couldn't find `gCred.json` in the path specified!")
 
         saveDir = os.path.dirname(self.settings.get("SettingsSave"))
         if mode == self.DriveCredentialsEnum.ADD:
@@ -244,8 +239,11 @@ class save:
         # decrypt / encrypt data
         key = Passcode.encode("utf-8")
 
-        result = self.enc.EncryptData(
-            result, key) if not decode else self.enc.DecryptData(result, key)
+        result = (
+            self.enc.EncryptData(result, key)
+            if not decode
+            else self.enc.DecryptData(result, key)
+        )
 
         return result, True, rBytes
 
@@ -295,12 +293,11 @@ class save:
             2: self.__jsonCoder,
             3: self.__pickeCoder,
             4: self.__cryptoCoder,
-            5: self.__csvCoder
+            5: self.__csvCoder,
         }
 
         for code in encoding:
-            result, rBytes, _ = _LOOKUP.get(code.value)(
-                result, decode, rBytes=rBytes)
+            result, rBytes, _ = _LOOKUP.get(code.value)(result, decode, rBytes=rBytes)
 
         return result, rBytes
 
@@ -335,8 +332,7 @@ class save:
 
         data, wByte = self.__CodeData(data, encoding)
 
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         return module.WriteData(data, path, wByte)
 
     def Read(self, path: str, encoding: typing.List = None) -> any:
@@ -350,8 +346,7 @@ class save:
             any: The data in the file
         """
         path, storage, encoding = self.__GetFileInformation(path, encoding)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
 
         rBytes = False
         for item in encoding:
@@ -377,8 +372,7 @@ class save:
         if storage is None:
             path, storage = self.__TranslateStorage(path)
 
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         module.credentials(self.settings)
         return module.MakeFolders(path)
 
@@ -389,8 +383,7 @@ class save:
             path (str): The path to remove that file
         """
         path, storage = self.__TranslateStorage(path)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         module.credentials(self.settings)
         module.DeleteFile(path)
 
@@ -401,7 +394,6 @@ class save:
             path (str): The path to remove the folder
         """
         path, storage = self.__TranslateStorage(path)
-        module: SaveModules.template.SaveTemplate = self.saveModules.get(
-            storage.name)
+        module: SaveModules.template.SaveTemplate = self.saveModules.get(storage.name)
         module.credentials(self.settings)
         module.DeleteFolder(path)
